@@ -1,5 +1,5 @@
 # autoconf -- create `configure' using m4 macros
-# Copyright 2001 Free Software Foundation, Inc.
+# Copyright (C) 2001, 2002 Free Software Foundation, Inc.
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ package Automake::Struct;
 
 ## See POD after __END__
 
-use 5.005;
+use 5.005_03;
 
 use strict;
 use vars qw(@ISA @EXPORT $VERSION);
@@ -564,8 +564,8 @@ Modified by Damian Conway, 1999-03-05, v0.58.
     Added classname prefixes to keys in hash-based classes
     (refer to "Perl Cookbook", Recipe 13.12 for rationale).
 
-    Corrected behaviour of accessors for '*@' and '*%' struct
-    elements.  Package now implements documented behaviour when
+    Corrected behavior of accessors for '*@' and '*%' struct
+    elements.  Package now implements documented behavior when
     returning a reference to an entire hash or array element.
     Previously these were returned as a reference to a reference
     to the element.
@@ -606,3 +606,20 @@ Originally C<Class::Template> by Dean Roehrich.
     # idea.
 
 =cut
+
+### Setup "GNU" style for perl-mode and cperl-mode.
+## Local Variables:
+## perl-indent-level: 2
+## perl-continued-statement-offset: 2
+## perl-continued-brace-offset: 0
+## perl-brace-offset: 0
+## perl-brace-imaginary-offset: 0
+## perl-label-offset: -2
+## cperl-indent-level: 2
+## cperl-brace-offset: 0
+## cperl-continued-brace-offset: 0
+## cperl-label-offset: -2
+## cperl-extra-newline-before-brace: t
+## cperl-merge-trailing-else: nil
+## cperl-continued-statement-offset: 2
+## End:
